==> FreeBSD-jasperreports-server-cp-4.7.0-maven-repository.zip: com/jaspersoft/jasperserver/api/engine/jasperreports/domain/impl/ReportUnitRequestBase.java <==
/*
 * Copyright (C) 2005 - 2011 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com.
 *
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 *
 * This program is free software: you can redistribute it and/or  modify
 * it under the terms of the GNU Affero General Public License  as
 * published by the Free Software Foundation, either version 3 of  the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero  General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public  License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package com.jaspersoft.jasperserver.api.engine.jasperreports.domain.impl;

import java.util.Map;
import java.util.concurrent.atomic.AtomicInteger;

import net.sf.jasperreports.engine.ReportContext;

import com.jaspersoft.jasperserver.api.common.domain.ExecutionContext;
import com.jaspersoft.jasperserver.api.engine.common.domain.Request;
import com.jaspersoft.jasperserver.api.engine.jasperreports.common.ReportExecuter;

/**
 * @author Lucian Chirita (lucianc@users.sourceforge.net)
 * @version $Id: ReportUnitRequestBase.java 23936 2012-05-28 09:30:59Z lchirita $
 */
public abstract class ReportUnitRequestBase implements Request {
	
	private static final AtomicInteger COUNTER = new AtomicInteger();
	
	private final String id;
	private Map reportParameters;
	private boolean asynchronous;
    private ReportContext reportContext;
    private boolean useDataSnapshot;
    private boolean recordDataSnapshot;
    
    private long startTime = System.currentTimeMillis();
    private boolean createAuditEvent;

	protected ReportUnitRequestBase(Map reportParameters) {
		this.id = System.identityHashCode(this) 
			+ "_" + System.currentTimeMillis() 
			+ "_" + COUNTER.incrementAndGet();

		this.reportParameters = reportParameters;
	}

	/**
	 *
	 */
	public Map getReportParameters()
	{
		return reportParameters;
	}

	/**
	 *
	 */
	public void setReportParameters(Map reportParameters)
	{
		this.reportParameters = reportParameters;
	}

	public String getId()
	{
		return id;
	}

	public boolean isAsynchronous() {
		return asynchronous;
	}

	public void setAsynchronous(boolean asynchronous) {
		this.asynchronous = asynchronous;
	}

	public boolean isUseDataSnapshot() {
		return useDataSnapshot;
	}

	public void setUseDataSnapshot(boolean useDataSnapshot) {
		this.useDataSnapshot = useDataSnapshot;
	}

	public boolean isRecordDataSnapshot() {
		return recordDataSnapshot;
	}

	public void setRecordDataSnapshot(boolean recordDataSnapshot) {
		this.recordDataSnapshot = recordDataSnapshot;
	}
	
	/**
	 * 
	 */
	public ReportContext getReportContext()
	{
		return reportContext;
	}

	/**
	 * 
	 */
	public void setReportContext(ReportContext reportContext)
	{
		this.reportContext = reportContext;//FIXME add this to the parameters automatically
	}

	public long getStartTime() {
		return startTime;
	}

	public void setStartTime(long startTime) {
		this.startTime = startTime;
	}

	public boolean isCreateAuditEvent() {
		return createAuditEvent;
	}

	public void setCreateAuditEvent(boolean createAuditEvent) {
		this.createAuditEvent = createAuditEvent;
	}

	public abstract ReportUnitResult execute(ExecutionContext context, ReportExecuter executer);

}

==> FreeBSD-jasperreports-server-cp-5.1.0-maven-repository.zip: com/jaspersoft/jasperserver/api/engine/jasperreports/domain/impl/ReportUnitRequestBase.java <==
/*
 * Copyright (C) 2005 - 2011 Jaspersoft Corporation. All rights reserved.
 * http://www.jaspersoft.com.
 *
 * Unless you have purchased  a commercial license agreement from Jaspersoft,
 * the following license terms  apply:
 *
 * This program is free software: you can redistribute it and/or  modify
 * it under the terms of the GNU Affero General Public License  as
 * published by the Free Software Foundation, either version 3 of  the
 * License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE. See the
 * GNU Affero  General Public License for more details.
 *
 * You should have received a copy of the GNU Affero General Public  License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
package com.jaspersoft.jasperserver.api.engine.jasperreports.domain.impl;

import com.jaspersoft.jasperserver.api.common.domain.ExecutionContext;
import com.jaspersoft.jasperserver.api.engine.common.domain.Request;
import com.jaspersoft.jasperserver.api.engine.jasperreports.common.ReportExecuter;
import net.sf.jasperreports.engine.JasperReportsContext;
import net.sf.jasperreports.engine.ReportContext;

import java.util.Map;
import java.util.concurrent.atomic.AtomicInteger;

/**
 * @author Lucian Chirita (lucianc@users.sourceforge.net)
 * @version $Id: ReportUnitRequestBase.java 28947 2013-02-26 15:02:08Z vsabadosh $
 */
public abstract class ReportUnitRequestBase implements Request {

	private static final AtomicInteger COUNTER = new AtomicInteger();
	
	private final String id;
	private Map reportParameters;
	private boolean asynchronous;
    private ReportContext reportContext;
    private boolean useDataSnapshot;
    private boolean recordDataSnapshot;
    
    private long startTime = System.currentTimeMillis();
    private boolean createAuditEvent;
    
    private JasperReportsContext jasperReportsContext;

	protected ReportUnitRequestBase(Map reportParameters) {
		this.id = System.identityHashCode(this) 
			+ "_" + System.currentTimeMillis() 
			+ "_" + COUNTER.incrementAndGet();

		this.reportParameters = reportParameters;
	}

	/**
	 *
	 */
	public Map getReportParameters()
	{
		return reportParameters;
	}

	/**
	 *
	 */
	public void setReportParameters(Map reportParameters)
	{
		this.reportParameters = reportParameters;
	}

	public String getId()
	{
		return id;
	}

	public boolean isAsynchronous() {
		return asynchronous;
	}

	public void setAsynchronous(boolean asynchronous) {
		this.asynchronous = asynchronous;
	}

	public boolean isUseDataSnapshot() {
		return useDataSnapshot;
	}

	public void setUseDataSnapshot(boolean useDataSnapshot) {
		this.useDataSnapshot = useDataSnapshot;
	}

	public boolean isRecordDataSnapshot() {
		return recordDataSnapshot;
	}

	public void setRecordDataSnapshot(boolean recordDataSnapshot) {
		this.recordDataSnapshot = recordDataSnapshot;
	}
	
	/**
	 * 
	 */
	public ReportContext getReportContext()
	{
		return reportContext;
	}

	/**
	 * 
	 */
	public void setReportContext(ReportContext reportContext)
	{
		this.reportContext = reportContext;//FIXME add this to the parameters automatically
	}

	public long getStartTime() {
		return startTime;
	}

	public void setStartTime(long startTime) {
		this.startTime = startTime;
	}

	public boolean isCreateAuditEvent() {
		return createAuditEvent;
	}

	public void setCreateAuditEvent(boolean createAuditEvent) {
		this.createAuditEvent = createAuditEvent;
	}

	public JasperReportsContext getJasperReportsContext() {
		return jasperReportsContext;
	}

	public void setJasperReportsContext(JasperReportsContext jasperReportsContext) {
		this.jasperReportsContext = jasperReportsContext;
	}

	public abstract ReportUnitResult execute(ExecutionContext context, ReportExecuter executer);

}
